# Variables

variable "user_data" {
  description = "Cloud Init 'user_data'"
  default = <<-EOF
              #!/bin/bash
              sudo apt update -y
              sudo apt-get -y install ca-certificates curl
              sudo install -y -m 0755 -d /etc/apt/keyrings
              sudo curl -fsSL https://download.docker.com/linux/ubuntu/gpg -o /etc/apt/keyrings/docker.asc
              sudo chmod a+r /etc/apt/keyrings/docker.asc

              # Add the repository to Apt sources:
              echo \
                "deb [arch=$(dpkg --print-architecture) signed-by=/etc/apt/keyrings/docker.asc] https://download.docker.com/linux/ubuntu \
                $(. /etc/os-release && echo "$VERSION_CODENAME") stable" | \
                sudo tee /etc/apt/sources.list.d/docker.list > /dev/null

              sudo apt-get update
              sudo apt-get install docker-ce docker-ce-cli containerd.io docker-buildx-plugin docker-compose-plugin
             EOF
}

variable "instance_size" {
  description = "Size of instance to create"
  default = "t2.micro"
}

variable "vpc_cidr" {
  description = "CIDR of VPC Subnet"
  default = "10.0.0.0/16"
}

variable "public_cidr" {
  description = "CIDR of Public Subnet"
  default = "10.0.1.0/24"
}

variable "aws_region" {
  description = "Region Preference"
  default = "us-west-2"
}

variable "aws_access_key" {
  description = "AWS Access Key"
  type = string
}

variable "aws_secret_key" {
  description = "AWS Secret Key"
  type = string
}
